import { App } from "aws-cdk-lib";
import { DataStack } from "./stacks/DataStack";
import { LambdaStack } from "./stacks/LambdaStack";
import { ApiStack } from "./stacks/ApiStack";
import { AuthStack } from "./stacks/AuthStack";
import { UiDeploymentStack } from "./stacks/UIDeploymentStack";

const contactapp = new App();

const dataStack = new DataStack(contactapp, "ContactAppDataStack");
const lambdaStack = new LambdaStack(contactapp, "ContactAppLambdaStack", {
  contactsTable: dataStack.contactsTable,
});
const authStack = new AuthStack(contactapp, "ContactAppAuthStack");
new ApiStack(contactapp, "ContactAppApiStack", {
  contactsLambdaIntegration: lambdaStack.contactsLambdaIntegration,
  userPool: authStack.userPool,
});
new UiDeploymentStack(contactapp, "ContactAppUIDeploymentStack");
