import { CfnOutput, Stack, StackProps } from "aws-cdk-lib";
import { Bucket } from "aws-cdk-lib/aws-s3";
import { Construct } from "constructs";
import { join } from "path";
import { existsSync } from "fs";
import { BucketDeployment, Source } from "aws-cdk-lib/aws-s3-deployment";
import { Distribution, OriginAccessIdentity } from "aws-cdk-lib/aws-cloudfront";
import { S3Origin } from "aws-cdk-lib/aws-cloudfront-origins";

export class UiDeploymentStack extends Stack {
  constructor(scope: Construct, id: string, props?: StackProps) {
    super(scope, id, props);

    const deploymentBucket = new Bucket(this, "uiDeploymentBucket", {
      bucketName: `contactapp-frontend`,
    });

    //Nalazimo dist folder za Front aplikaciju
    const uiDir = join(__dirname, "..", "..", "..", "..", "frontend", "build");

    //Da li dist folder postoji
    if (!existsSync(uiDir)) {
      console.warn("Ui dir not found: " + uiDir);
      return;
    }

    new BucketDeployment(this, "ContactAppDeployment", {
      destinationBucket: deploymentBucket,
      sources: [Source.asset(uiDir)],
    });

    const originIdentity = new OriginAccessIdentity(
      this,
      "OriginAccessIdentity"
    );
    deploymentBucket.grantRead(originIdentity);

    const distribution = new Distribution(this, "ContactAppDistribution", {
      defaultRootObject: "index.html",
      defaultBehavior: {
        origin: new S3Origin(deploymentBucket, {
          originAccessIdentity: originIdentity, //Distribucija ima pravo da cita iz deploymentBucket-a
        }),
      },
    });

    new CfnOutput(this, "ContactAppUrl", {
      value: distribution.distributionDomainName,
    });
  }
}
