import { DynamoDBClient, UpdateItemCommand } from "@aws-sdk/client-dynamodb";
import { APIGatewayProxyEvent, APIGatewayProxyResult } from "aws-lambda";
import { marshall } from "@aws-sdk/util-dynamodb";
import { parseJSON } from "../shared/Utils";

export async function updateContact(
  event: APIGatewayProxyEvent,
  ddbClient: DynamoDBClient
): Promise<APIGatewayProxyResult> {
  if (event.queryStringParameters && "id" in event.queryStringParameters) {
    const entityId = event.queryStringParameters["id"];

    const entries = Object.entries(parseJSON(event.body));

    // set #var1 = :var1, #var2 = :var2, ...
    const UpdateExpression =
      "set " + entries.map((entry) => `#${entry[0]} = :${entry[0]}`).join(", ");

    // { #var1: var1, #var2: var2, ... }
    const ExpressionAttributeNames = entries.reduce(
      (mapOut, entry) => ({ ...mapOut, ["#" + entry[0]]: entry[0] }),
      {}
    );

    // { :var1: { [type1]: val1 }, :var2: { [type2]: val2 }, ... }
    const ExpressionAttributeValues = entries.reduce(
      (mapOut, entry) => ({ ...mapOut, [":" + entry[0]]: marshall(entry[1]) }),
      {}
    );

    const updateResponse = await ddbClient.send(
      new UpdateItemCommand({
        TableName: process.env.TABLE_NAME,
        Key: {
          id: { S: entityId },
        },
        UpdateExpression,
        ExpressionAttributeNames,
        ExpressionAttributeValues,
        ReturnValues: "UPDATED_NEW",
      })
    );

    return {
      statusCode: 204,
      body: JSON.stringify(updateResponse.Attributes),
    };
  }

  return {
    statusCode: 400,
    body: JSON.stringify("Please provide the right arguments"),
  };
}
