import { DynamoDBClient } from "@aws-sdk/client-dynamodb";
import {
  APIGatewayProxyEvent,
  APIGatewayProxyResult,
  Context,
} from "aws-lambda";
import { getContacts } from "./GetContacts";
import { postContacts } from "./PostContacts";
import { updateContact } from "./UpdateContact";
import { deleteContact } from "./DeleteContact";
import { addCorsHeader } from "../shared/Utils";

const ddbClient = new DynamoDBClient({});

async function handler(
  event: APIGatewayProxyEvent,
  context: Context
): Promise<APIGatewayProxyResult> {
  let response: APIGatewayProxyResult;

  try {
    switch (event.httpMethod) {
      case "GET":
        const getResponse = await getContacts(event, ddbClient);
        response = getResponse;
        break;
      case "POST":
        const postResponse = await postContacts(event, ddbClient);
        response = postResponse;
        break;
      case "PUT":
        const putResponse = await updateContact(event, ddbClient);
        response = putResponse;
        break;
      case "DELETE":
        const deleteResponse = await deleteContact(event, ddbClient);
        console.log(deleteResponse);
        response = deleteResponse;
        break;
      default:
        break;
    }
  } catch (error) {
    return {
      statusCode: 500,
      body: JSON.stringify(error.message),
    };
  }

  addCorsHeader(response);
  return response;
}

export { handler };
