import { api } from "api";
import {
  createContact,
  /*deleteImageFromS3,
  deleteManyContacts,*/
  deleteOneContact,
  editContact,
  getAllContacts,
  getContactById,
  /*  uploadImageToS3, */
} from "api/asyncFunctions/contacts";

const contactsApiEndpoints = api.injectEndpoints({
  endpoints: (build) => ({
    getAllContacts: build.query({
      queryFn: async (jwtToken) => {
        const result = await getAllContacts(jwtToken);
        return result;
      },
      providesTags: ["Contact"],
    }),
    getContactById: build.query({
      queryFn: async ({ contactId, jwtToken }) => {
        const result = await getContactById(contactId, jwtToken);
        return result;
      },
      providesTags: ["Contact"],
    }),
    createContact: build.mutation({
      queryFn: async ({ contact, jwtToken }) => {
        const result = await createContact(contact, jwtToken);
        return result;
      },
      invalidatesTags: ["Contact"],
    }),
    editContact: build.mutation({
      queryFn: async ({ contactId, contact, jwtToken }) => {
        const result = await editContact(contactId, contact, jwtToken);
        return result;
      },
      invalidatesTags: ["Contact"],
    }),
    deleteOneContact: build.mutation({
      queryFn: async ({ contactId, jwtToken }) => {
        const result = await deleteOneContact(contactId, jwtToken);
        return result;
      },
      invalidatesTags: ["Contact"],
    }),
  }),
});

/* const contactsApiEndpoints = api.injectEndpoints({
  endpoints: (build) => ({
    getAllContacts: build.query({
      queryFn: getAllContacts,
      providesTags: ["Contact"],
    }),
    /*   getContactById: build.query({
      queryFn: getContactById,
      providesTags: ["Contact"],
    }),
    createContact: build.mutation({
      queryFn: createContact,
      invalidatesTags: ["Contact"],
    }),
    uploadImageToS3: build.mutation({
      queryFn: uploadImageToS3,
      invalidatesTags: ["Contact"],
    }),
    deleteImageFromS3: build.mutation({
      queryFn: deleteImageFromS3,
      invalidatesTags: ["Contact"],
    }),
    editContact: build.mutation({
      queryFn: editContact,
      invalidatesTags: ["Contact"],
    }),
    deleteOneContact: build.mutation({
      queryFn: deleteOneContact,
      invalidatesTags: ["Contact"],
    }),
    deleteManyContacts: build.mutation({
      queryFn: deleteManyContacts,
      invalidatesTags: ["Contact"],
    }), 
  }),
  overrideExisting: false,
}); */

export const {
  useGetAllContactsQuery,
  useGetContactByIdQuery,
  useCreateContactMutation,
  /*useUploadImageToS3Mutation,
  useDeleteImageFromS3Mutation,*/
  useEditContactMutation,
  useDeleteOneContactMutation,
  /* useDeleteManyContactsMutation, */
} = contactsApiEndpoints;
