import ReactDOM from "react-dom/client";
import { BrowserRouter } from "react-router-dom";
import { HelmetProvider } from "react-helmet-async";
import { Provider } from "react-redux";

import App from "./App";
import { store } from "store";
import { CollapseDrawerProvider } from "./contexts/CollapseDrawerContext";

import { Amplify } from "aws-amplify";

const awsRegion = "eu-north-1";

Amplify.configure({
  Auth: {
    mandatorySignIn: false,
    region: awsRegion,
    userPoolId: "eu-north-1_EnVsgMUrv",
    userPoolWebClientId: "26k3mhp8iitp5oong2ea67g3ld",
    identityPoolId: "eu-north-1:f0fb861a-9bcc-40dd-a919-9b86ff6ec81f",
    authenticationFlowType: "USER_PASSWORD_AUTH",
  },
  API: {
    endpoints: [
      {
        name: "contactsApi",
        endpoint:
          "https://ntwa190r07.execute-api.eu-north-1.amazonaws.com/prod/",
      },
    ],
  },
});

const root = ReactDOM.createRoot(
  document.getElementById("root") as HTMLElement
);
root.render(
  <HelmetProvider>
    <CollapseDrawerProvider>
      <Provider store={store}>
        <BrowserRouter>
          <App />
        </BrowserRouter>
      </Provider>
    </CollapseDrawerProvider>
  </HelmetProvider>
);
