import Page from "components/Page";
import ContactForm from "./ContactForm";
import { SingeContactFormValues, UnsavedContactEntry } from "types";
import { useCreateContactMutation } from "api/contacts";
import { useAppSelector } from "hooks/storeHooks";
import { useNavigate } from "react-router-dom";
import { CONTACTS_ROUTES } from "routes/paths";

export default function CreateContact() {
  const navigate = useNavigate();
  const [createContact, { data, isLoading, isError }] =
    useCreateContactMutation();

  const jwtToken = useAppSelector(
    (state) => state.user.authUser.signInUserSession.idToken.jwtToken
  );

  const handleCreate = (value: SingeContactFormValues) => {
    const unsavedContact: UnsavedContactEntry = {
      ...value,
      isFavorite: false,
    };
    createContact({ contact: unsavedContact, jwtToken: jwtToken });

    navigate(CONTACTS_ROUTES.list);
  };
  return (
    <Page title="Create new contact">
      <ContactForm
        title="Create new contact"
        buttonName="Create"
        onSubmit={handleCreate}
      />
    </Page>
  );
}
